// ignore_for_file: always_specify_types, type_annotate_public_apis, invalid_annotation_target, depend_on_referenced_packages

import 'package:freezed_annotation/freezed_annotation.dart';
import 'package:sghi_core/afya_moja_core/afya_moja_core.dart';
import 'package:sghi_core/communities/models/message.dart';

part 'room.freezed.dart';
part 'room.g.dart';

@Freezed(makeCollectionsUnmodifiable: false)
class Room with _$Room {
  factory Room({
    @JsonKey(name: 'room_id') String? roomID,
    @JsonKey(name: 'name') String? name,
    @JsonKey(name: 'canonical_alias') String? alias,
    @JsonKey(name: 'topic') String? topic,
    @JsonKey(name: 'avatar_url') String? avatarUri,
    @JsonKey(name: 'num_joined_members') int? totalJoinedMembers,

    // Room events from sync
    @JsonKey(name: 'timeline') RoomTimeline? timeline,
    @JsonKey(name: 'state') RoomState? state,
    @JsonKey(name: 'ephemeral') Ephemeral? ephemeral,
    @JsonKey(name: 'unread_notifications')
        RoomUnreadNotifications? unreadNotifications,
    @JsonKey(name: 'summary') RoomSummary? summary,

    // For invited rooms
    @JsonKey(name: 'invite_state') InviteEventState? inviteState,
    @JsonKey(name: 'invite') bool? invite,
    @JsonKey(name: 'm.heroes') List<String?>? onlineMembers,
  }) = _Room;

  factory Room.fromJson(Map<String, dynamic> json) => _$RoomFromJson(json);

  factory Room.initial() => Room(
        roomID: UNKNOWN,
        name: UNKNOWN,
        topic: UNKNOWN,
        avatarUri: UNKNOWN,
        totalJoinedMembers: 0,
        timeline: RoomTimeline.initial(),
        state: RoomState.initial(),
        ephemeral: Ephemeral.initial(),
        unreadNotifications: RoomUnreadNotifications.initial(),
        summary: RoomSummary.initial(),
        inviteState: InviteEventState.initial(),
        invite: false,
      );
}

@Freezed(makeCollectionsUnmodifiable: false)
class RoomTimeline with _$RoomTimeline {
  factory RoomTimeline({
    @JsonKey(name: 'events') List<Message?>? events,
    @JsonKey(name: 'prev_batch') String? prevBatch,
    @JsonKey(name: 'limited', defaultValue: false) bool? limited,
  }) = _RoomTimeline;

  factory RoomTimeline.fromJson(Map<String, dynamic> json) =>
      _$RoomTimelineFromJson(json);

  factory RoomTimeline.initial() => RoomTimeline(
        events: <Message>[],
        prevBatch: UNKNOWN,
        limited: false,
      );
}

@Freezed(makeCollectionsUnmodifiable: false)
class RoomState with _$RoomState {
  factory RoomState({
    @JsonKey(name: 'events') List<Message?>? events,
  }) = _RoomState;

  factory RoomState.fromJson(Map<String, dynamic> json) =>
      _$RoomStateFromJson(json);

  factory RoomState.initial() => RoomState(
        events: <Message>[],
      );
}

@freezed
class Ephemeral with _$Ephemeral {
  factory Ephemeral({
    @JsonKey(name: 'events') List<Message?>? events,
  }) = _Ephemeral;

  factory Ephemeral.fromJson(Map<String, dynamic> json) =>
      _$EphemeralFromJson(json);

  factory Ephemeral.initial() => Ephemeral(
        events: <Message>[],
      );
}

@freezed
class RoomUnreadNotifications with _$RoomUnreadNotifications {
  factory RoomUnreadNotifications({
    @JsonKey(name: 'notification_count', defaultValue: 0)
        int? notificationCount,
    @JsonKey(name: 'highlight_count', defaultValue: 0) int? highlightCount,
  }) = _RoomUnreadNotifications;

  factory RoomUnreadNotifications.fromJson(Map<String, dynamic> json) =>
      _$RoomUnreadNotificationsFromJson(json);

  factory RoomUnreadNotifications.initial() => RoomUnreadNotifications(
        notificationCount: 0,
        highlightCount: 0,
      );
}

@freezed
class RoomSummary with _$RoomSummary {
  factory RoomSummary({
    @JsonKey(name: 'm.joined_member_count', defaultValue: 0) int? joinedMembers,
    @JsonKey(name: 'm.invited_member_count', defaultValue: 0)
        int? invitedMembers,
  }) = _RoomSummary;

  factory RoomSummary.fromJson(Map<String, dynamic> json) =>
      _$RoomSummaryFromJson(json);

  factory RoomSummary.initial() => RoomSummary(
        joinedMembers: 0,
        invitedMembers: 0,
      );
}

@freezed
class InviteEventState with _$InviteEventState {
  factory InviteEventState({
    @JsonKey(name: 'events') List<Message?>? events,
  }) = _InviteEventState;

  factory InviteEventState.fromJson(Map<String, dynamic> json) =>
      _$InviteEventStateFromJson(json);

  factory InviteEventState.initial() => InviteEventState(events: <Message>[]);
}
