import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:sghi_core/domain_objects/value_objects/enums.dart';
import 'package:sghi_core/ui_components/src/app_strings.dart';
import 'package:sghi_core/ui_components/src/profile_avatar.dart';

void main() {
  /// [_wut] represents widgetUnderTest

  //aleGender and femaleGender represent the gender received from the user logged in session
  final String maleGender = Gender.male.toString();
  final String femaleGender = Gender.female.toString();

  //!Unit tests
  group('SILProfileAvatar:', () {
    // maleGender and femaleGender represent the gender received from the user logged in session
    final String maleGender = Gender.male.toString();
    final String femaleGender = Gender.female.toString();

    test(
        'SILProfileAvatar sets male to photoPath when the male gender is passed',
        () {
      final SILProfileAvatar _wut = SILProfileAvatar(
        photoPath: maleGender == Gender.male.toString()
            ? maleUserIconPath
            : femaleUserIconPath,
      );

      expect(_wut.photoPath, maleUserIconPath);
    });
    test(
        'SILProfileAvatar sets female to photoPath when the female gender is passed',
        () {
      final SILProfileAvatar _wut = SILProfileAvatar(
          photoPath: femaleGender == Gender.female.toString()
              ? femaleUserIconPath
              : maleUserIconPath);
      expect(_wut.photoPath, femaleUserIconPath);
    });
  });

  //!Widget tests
  group('SILProfileAvatar:', () {
    testWidgets('Male icon displayed when male gender is passed',
        (WidgetTester tester) async {

      //execute the test itself
      await tester.pumpWidget(MaterialApp(
        home: SILProfileAvatar(
          photoPath: maleGender == Gender.male.toString()
              ? maleUserIconPath
              : femaleUserIconPath,
        ),
      ));

      expect(find.image(const AssetImage(maleUserIconPath)), findsOneWidget);
    });

    testWidgets('Female icon displayed when female gender is passed',
        (WidgetTester tester) async {

      //execute the test itself
      await tester.pumpWidget(MaterialApp(
        home: SILProfileAvatar(
            photoPath: femaleGender == Gender.female.toString()
                ? femaleUserIconPath
                : maleUserIconPath),
      ));

      expect(find.image(const AssetImage(femaleUserIconPath)), findsOneWidget);
    });
  });
}
